@@ -757,10 +757,10 @@ withinsumsq <- function(n, p, replic, k, parallel, seed) {
 
 .onAttach <- function(libname, pkgname) {
 
-   SSver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname),
+   SSver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname), 
                      fields="Version")
-   packageStartupMessage(paste(pkgname, SSver))
-   packageStartupMessage("Type MVR.news() to see new features, changes, and bug fixes\n")
-
+   packageStartupMessage(paste(pkgname, " ", SSver, sep=""))
+   packageStartupMessage("Type MVR.news() to see new features, changes, and bug fixes")
+   
 }
 ##########################################################################################################################################
